==> zio-aws-elasticsearch_3-5.17.115.1-sources.jar: zio/aws/elasticsearch/model/StorageType.scala <==
package zio.aws.elasticsearch.model
import zio.aws.elasticsearch.model.primitives.{
  StorageSubTypeName,
  StorageTypeName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class StorageType(
    storageTypeName: Option[StorageTypeName] = None,
    storageSubTypeName: Option[StorageSubTypeName] = None,
    storageTypeLimits: Option[
      Iterable[zio.aws.elasticsearch.model.StorageTypeLimit]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.StorageType = {
    import StorageType.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.StorageType
      .builder()
      .optionallyWith(
        storageTypeName.map(value =>
          StorageTypeName.unwrap(value): java.lang.String
        )
      )(_.storageTypeName)
      .optionallyWith(
        storageSubTypeName.map(value =>
          StorageSubTypeName.unwrap(value): java.lang.String
        )
      )(_.storageSubTypeName)
      .optionallyWith(
        storageTypeLimits.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.storageTypeLimits)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.StorageType.ReadOnly =
    zio.aws.elasticsearch.model.StorageType.wrap(buildAwsValue())
}
object StorageType {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.StorageType
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.StorageType =
      zio.aws.elasticsearch.model.StorageType(
        storageTypeName.map(value => value),
        storageSubTypeName.map(value => value),
        storageTypeLimits.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def storageTypeName: Option[StorageTypeName]
    def storageSubTypeName: Option[StorageSubTypeName]
    def storageTypeLimits
        : Option[List[zio.aws.elasticsearch.model.StorageTypeLimit.ReadOnly]]
    def getStorageTypeName: ZIO[Any, AwsError, StorageTypeName] =
      AwsError.unwrapOptionField("storageTypeName", storageTypeName)
    def getStorageSubTypeName: ZIO[Any, AwsError, StorageSubTypeName] =
      AwsError.unwrapOptionField("storageSubTypeName", storageSubTypeName)
    def getStorageTypeLimits: ZIO[Any, AwsError, List[
      zio.aws.elasticsearch.model.StorageTypeLimit.ReadOnly
    ]] = AwsError.unwrapOptionField("storageTypeLimits", storageTypeLimits)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.StorageType
  ) extends zio.aws.elasticsearch.model.StorageType.ReadOnly {
    override val storageTypeName: Option[StorageTypeName] = scala
      .Option(impl.storageTypeName())
      .map(value =>
        zio.aws.elasticsearch.model.primitives.StorageTypeName(value)
      )
    override val storageSubTypeName: Option[StorageSubTypeName] = scala
      .Option(impl.storageSubTypeName())
      .map(value =>
        zio.aws.elasticsearch.model.primitives.StorageSubTypeName(value)
      )
    override val storageTypeLimits
        : Option[List[zio.aws.elasticsearch.model.StorageTypeLimit.ReadOnly]] =
      scala
        .Option(impl.storageTypeLimits())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.elasticsearch.model.StorageTypeLimit.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.StorageType
  ): zio.aws.elasticsearch.model.StorageType.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticsearch_3-5.19.31.1-sources.jar: zio/aws/elasticsearch/model/StorageType.scala <==
package zio.aws.elasticsearch.model
import zio.aws.elasticsearch.model.primitives.{
  StorageSubTypeName,
  StorageTypeName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class StorageType(
    storageTypeName: Optional[StorageTypeName] = Optional.Absent,
    storageSubTypeName: Optional[StorageSubTypeName] = Optional.Absent,
    storageTypeLimits: Optional[
      Iterable[zio.aws.elasticsearch.model.StorageTypeLimit]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.StorageType = {
    import StorageType.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.StorageType
      .builder()
      .optionallyWith(
        storageTypeName.map(value =>
          StorageTypeName.unwrap(value): java.lang.String
        )
      )(_.storageTypeName)
      .optionallyWith(
        storageSubTypeName.map(value =>
          StorageSubTypeName.unwrap(value): java.lang.String
        )
      )(_.storageSubTypeName)
      .optionallyWith(
        storageTypeLimits.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.storageTypeLimits)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.StorageType.ReadOnly =
    zio.aws.elasticsearch.model.StorageType.wrap(buildAwsValue())
}
object StorageType {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.StorageType
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.StorageType =
      zio.aws.elasticsearch.model.StorageType(
        storageTypeName.map(value => value),
        storageSubTypeName.map(value => value),
        storageTypeLimits.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def storageTypeName: Optional[StorageTypeName]
    def storageSubTypeName: Optional[StorageSubTypeName]
    def storageTypeLimits
        : Optional[List[zio.aws.elasticsearch.model.StorageTypeLimit.ReadOnly]]
    def getStorageTypeName: ZIO[Any, AwsError, StorageTypeName] =
      AwsError.unwrapOptionField("storageTypeName", storageTypeName)
    def getStorageSubTypeName: ZIO[Any, AwsError, StorageSubTypeName] =
      AwsError.unwrapOptionField("storageSubTypeName", storageSubTypeName)
    def getStorageTypeLimits: ZIO[Any, AwsError, List[
      zio.aws.elasticsearch.model.StorageTypeLimit.ReadOnly
    ]] = AwsError.unwrapOptionField("storageTypeLimits", storageTypeLimits)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.StorageType
  ) extends zio.aws.elasticsearch.model.StorageType.ReadOnly {
    override val storageTypeName: Optional[StorageTypeName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.storageTypeName())
        .map(value =>
          zio.aws.elasticsearch.model.primitives.StorageTypeName(value)
        )
    override val storageSubTypeName: Optional[StorageSubTypeName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.storageSubTypeName())
        .map(value =>
          zio.aws.elasticsearch.model.primitives.StorageSubTypeName(value)
        )
    override val storageTypeLimits: Optional[
      List[zio.aws.elasticsearch.model.StorageTypeLimit.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.storageTypeLimits())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticsearch.model.StorageTypeLimit.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.StorageType
  ): zio.aws.elasticsearch.model.StorageType.ReadOnly = new Wrapper(impl)
}
